@@ -13,6 +13,12 @@ function(x, lev=95)
       ud<-x[[i]]$UD
       ud[ud>lev]<-NA
       ud[!is.na(ud)]<-1
+      jj <- labcon(ud)
+      jj <- table(factor(c(jj)))
+      if (any(jj<4))
+        stop("Some parts of the home range contain less than 3 pixels.
+Increase the size of the grid used for the estimation in
+the function 'kernelUD' (parameter 'grid') and try again")
       contour[[i]]<-getcontour(ud)
     }
     names(contour)<-names(x)
