@@ -1,16 +1,16 @@
-plot.ltraj <- function (x, id = unique(unlist(lapply(x, attr, which="id"))), 
+plot.ltraj <- function (x, id = unique(unlist(lapply(x, attr, which="id"))),
                         burst = unlist(lapply(x, attr, which="burst")),
                         asc = NULL, area = NULL, xlim = NULL,
                         ylim = NULL, colasc = gray((240:1)/256),
-                        colpol = "green", addpoints = TRUE, 
-                        addlines = TRUE, perani = TRUE, final = TRUE, ...) 
+                        colpol = "green", addpoints = TRUE,
+                        addlines = TRUE, perani = TRUE, final = TRUE, ...)
 {
   polygon <- area
   if (!is.null(area)) {
-    if (!inherits(area, "area")) 
+    if (!inherits(area, "area"))
       stop("area should be an object of class area")
   }
-  if (!inherits(x, "ltraj")) 
+  if (!inherits(x, "ltraj"))
     stop("x should be an object of class ltraj")
 
   ## supprimer les NA
@@ -30,13 +30,13 @@ plot.ltraj <- function (x, id = unique(unlist(lapply(x, attr, which="id"))),
   x$burst <- factor(x$burst)
   bu <- levels(x$burst)
   burst <- burst[burst%in%bu]
-  
+
   i <- split(x, x$burst)
   x <- do.call("rbind", i[burst])
   x$id <- factor(x$id)
   x$burst <- factor(x$burst)
 
-  if (!perani) 
+  if (!perani)
     idc <- "burst"
   else idc <- "id"
   li <- split(x, x[[idc]])
@@ -46,7 +46,7 @@ plot.ltraj <- function (x, id = unique(unlist(lapply(x, attr, which="id"))),
   m <- unlist(lapply(li, function(x) mean(x$date)))
   nli <- names(li)
   nli <- nli[order(m)]
-  
+
   if (is.null(xlim)) {
     maxxl <- max(unlist(lapply(li, function(ki) range(ki$x)[2] - range(ki$x)[1])))
     xlim <- lapply(li, function(ki) c(min(ki$x), min(ki$x)+maxxl))
@@ -59,20 +59,20 @@ plot.ltraj <- function (x, id = unique(unlist(lapply(x, attr, which="id"))),
     maxyl <- max(unlist(lapply(li, function(ki) range(ki$y)[2] - range(ki$y)[1])))
     ylim <- lapply(li, function(ki) c(min(ki$y), min(ki$y)+maxyl))
   } else {
-    ma <- max(unlist(lapply(li, function(i) range(ki$y)[2])))
-    mi <- min(unlist(lapply(li, function(i) range(ki$y)[1])))
+    ma <- max(unlist(lapply(li, function(ki) range(ki$y)[2])))
+    mi <- min(unlist(lapply(li, function(ki) range(ki$y)[1])))
     ylim <- lapply(li, function(ki) c(mi,ma))
   }
   names(xlim) <- names(li)
   names(ylim) <- names(li)
-  
+
   for (i in nli) {
-    if (!is.null(asc)) 
-      image(asc, col = colasc, xlim = xlim[i][[1]], ylim = ylim[i][[1]], 
+    if (!is.null(asc))
+      image(asc, col = colasc, xlim = xlim[i][[1]], ylim = ylim[i][[1]],
             main = i,
             axes = (length(li)==1), ...)
     else plot(li[i][[1]]$x, li[i][[1]]$y, type = "n", asp = 1,
-              xlim = xlim[i][[1]], 
+              xlim = xlim[i][[1]],
               ylim = ylim[i][[1]], axes = (length(li)==1),
               main = i, ...)
     box()
@@ -87,14 +87,14 @@ plot.ltraj <- function (x, id = unique(unlist(lapply(x, attr, which="id"))),
     }
     if (addpoints) {
       for (j in levels(factor(li[[i]]$burst))) {
-        points(x$x[x$burst == j], x$y[x$burst == j], 
+        points(x$x[x$burst == j], x$y[x$burst == j],
                pch = 21, col = "black", bg = "white")
       }
     }
     if (final) {
       for (j in levels(factor(li[[i]]$burst))) {
-        points(x$x[x$burst == j][c(1, length(x$x[x$burst == 
-                     j]))], x$y[x$burst == j][c(1, length(x$y[x$burst == 
+        points(x$x[x$burst == j][c(1, length(x$x[x$burst ==
+                     j]))], x$y[x$burst == j][c(1, length(x$y[x$burst ==
                                   j]))], pch = 14, col = c("blue", "red"))
       }
     }
